@@ -8,7 +8,6 @@
 
 #include <set>
 #include <stdexcept>
-#include <boost/lexical_cast.hpp>
 
 #if defined(__APPLE__) && defined(__MACH__) && defined(__GNUC__) \
  && __GNUC__ == 3 && __GNUC_MINOR__ <= 4 && !defined(__APPLE_CC__)
@@ -128,7 +127,7 @@ namespace // <unnamed>
   }
 #endif // BOOST_PYTHON_CONVERTER_REGISTRY_APPLE_MACH_WORKAROUND
 
-  entry* get(type_info type)
+  entry* get(type_info type, bool is_shared_ptr = false)
   {
 #  ifdef BOOST_PYTHON_TRACE_REGISTRY
       registry_t::iterator p = entries().find(entry(type));
@@ -138,7 +137,7 @@ namespace // <unnamed>
                     ? "...NOT found\n" : "...found\n");
 #  endif
       std::pair<registry_t::const_iterator,bool> pos_ins
-          = entries().insert(entry(type));
+          = entries().insert(entry(type,is_shared_ptr));
       
 #  if __MWERKS__ >= 0x3000
       // do a little invariant checking if a change was made
@@ -161,9 +160,9 @@ namespace registry
       assert(slot == 0); // we have a problem otherwise
       if (slot != 0)
       {
-          std::string msg(
-              "to-Python converter for "
-              + lexical_cast<std::string>(source_t)
+          std::string msg = (
+              std::string("to-Python converter for ")
+              + source_t.name()
               + " already registered; second conversion method ignored."
           );
           
@@ -230,6 +229,11 @@ namespace registry
       return *get(key);
   }
 
+  registration const& lookup_shared_ptr(type_info key)
+  {
+      return *get(key, true);
+  }
+
   registration const* query(type_info type)
   {
       registry_t::iterator p = entries().find(entry(type));
