@@ -13,12 +13,20 @@
     license reproduced at the end of this file.
 =============================================================================*/
 
-// Tests error reporting: illegal #if expressions. 
+// Tests error reporting: #define syntax errors.
 
-// 14.4: Unbalanced parenthesis in #if defined operator.
-//E t_6_009.cpp(20): error: ill formed preprocessor expression: defined()
-#if defined ( MACRO
-#endif
+// 18.9:    No space between macro name and replacement text.
+//    C90 (Corrigendum 1) forbids this if and only if the replacement text 
+//        begins with a non-basic-character.
+//    C99 forbids this even when the replacement text begins with basic-
+//        character.
+
+//  From ISO 9899:1990 / Corrigendum 1. 
+//E t_6_038.cpp(26): error: ill formed preprocessor directive: #define
+#define THIS$AND$THAT(a, b)     ((a) + (b))
+
+// Note: the following definition is legal (object-like macro).
+//       #define THIS $AND$THAT(a, b)    ((a) + (b))
 
 /*-
  * Copyright (c) 1998, 2002-2005 Kiyoshi Matsui <kmatsui@t3.rim.or.jp>
